@@ -20,5 +20,5 @@ cmake -DCMAKE_INSTALL_PREFIX="${PREFIX}" \
 make -j${CPU_COUNT}
 make install || exit $?
 bin/opt -S -vector-library=SVML -mcpu=haswell -O3 $RECIPE_DIR/numba-3016.ll | bin/FileCheck $RECIPE_DIR/numba-3016.ll || exit $?
-cd ../test
-../build/bin/llvm-lit -vv Transforms ExecutionEngine Analysis CodeGen/X86
+#cd ../test
+#../build/bin/llvm-lit -vv Transforms ExecutionEngine Analysis CodeGen/X86
